* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog)
  * Business Capabilities in the Reference Catalog
